@@ -21,17 +21,21 @@
   
 */
 
+#include <config.h>
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <string.h>
 
-#include "gyrus-i18n.h"
+#include "glib/gi18n.h"
 #include "gyrus-main-app.h"
 #include "gyrus-admin.h"
 #include "gyrus-common.h"
 #include "gyrus-session.h"
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-admin-acl.h"
+#include "gyrus-marshal.h"
+
 
 /* #define DEBUG_PLAIN_CHANNEL*/
 
@@ -40,10 +44,12 @@ static void gyrus_admin_init (GyrusAdmin *admin);
 static void gyrus_admin_finalize (GObject *object);
 static void gyrus_admin_destroy (GtkObject *object);
 
-static void gyrus_admin_initialize_users_tree_view (GyrusAdmin *admin);
+static void gyrus_admin_initialize_mailbox_tree_view (GyrusAdmin *admin, 
+						      gboolean is_orphaned);
 static void gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin);
-GtkTreeModel * gyrus_admin_users_treemodel_new (void);
-GtkTreeModel * gyrus_admin_acl_treemodel_new (void);
+
+GtkTreeModel * gyrus_admin_mailbox_tree_model_new (void);
+GtkListStore * gyrus_admin_acl_tree_model_new (void);
 
 void gyrus_admin_on_button_connect_clicked (GtkButton *button,
 					    gpointer user_data);
@@ -58,12 +64,9 @@ void
 gyrus_admin_on_acl_selection_changed (GtkTreeSelection *selection,
 				      gpointer user_data);
 
-gboolean
+void
 gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
-					GtkTreeModel *model,
-					GtkTreePath *path,
-					gboolean path_currently_selected,
-					gpointer data);
+					gpointer user_data);
 
 void gyrus_admin_on_renderer_toggled (GtkCellRendererToggle *renderer,
 				      gchar *path,
@@ -115,10 +118,63 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
 
+	GType selection_changed_types [1] = {
+		G_TYPE_BOOLEAN
+	};
+	
 	parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->finalize = gyrus_admin_finalize;
 	object_class->destroy = gyrus_admin_destroy;
+	
+	class->connected_signal_id = 
+		g_signal_newv ("connected", 
+			       G_TYPE_FROM_CLASS (class),
+			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+			       NULL /* class closure */,
+			       NULL /* accumulator */,
+			       NULL /* accu_data */,
+			       g_cclosure_marshal_VOID__VOID,
+			       G_TYPE_NONE /* return_type */,
+			       0     /* n_params */,
+			       NULL  /* param_types */);
+
+	class->disconnected_signal_id = 
+		g_signal_newv ("disconnected", 
+			       G_TYPE_FROM_CLASS (class),
+			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+			       NULL /* class closure */,
+			       NULL /* accumulator */,
+			       NULL /* accu_data */,
+			       g_cclosure_marshal_VOID__VOID,
+			       G_TYPE_NONE /* return_type */,
+			       0     /* n_params */,
+			       NULL  /* param_types */);
+
+	class->acl_entry_selection_changed = 
+		g_signal_newv ("acl-entry-selection-changed", 
+			       G_TYPE_FROM_CLASS (class),
+			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+			       NULL /* class closure */,
+			       NULL /* accumulator */,
+			       NULL /* accu_data */,
+			       gyrus_VOID__BOOLEAN,
+			       G_TYPE_NONE /* return_type */,
+			       1     /* n_params */,
+			       selection_changed_types /* param_types */);
+
+	class->mailbox_selection_changed = 
+		g_signal_newv ("mailbox-selection-changed", 
+			       G_TYPE_FROM_CLASS (class),
+			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+			       NULL /* class closure */,
+			       NULL /* accumulator */,
+			       NULL /* accu_data */,
+			       gyrus_VOID__BOOLEAN,
+			       G_TYPE_NONE /* return_type */,
+			       1     /* n_params */,
+			       selection_changed_types /* param_types */);
+
 }
 
 static void
@@ -138,6 +194,9 @@ gyrus_admin_init_get_widgets (GyrusAdmin *admin)
 	priv->treeview_users =
 		GTK_TREE_VIEW (glade_xml_get_widget (xml_page,
 						     "treeview_users"));
+	priv->treeview_corrupt_mailbox = 
+		GTK_TREE_VIEW (glade_xml_get_widget (xml_page, 
+						     "treeview_corrupt_mailbox"));
 	priv->treeview_acl =
 		GTK_TREE_VIEW (glade_xml_get_widget (xml_page,
 						     "treeview_acl"));
@@ -209,8 +268,9 @@ gyrus_admin_init (GyrusAdmin *admin)
 	admin->priv->session = NULL;
 	
 	gyrus_admin_init_get_widgets (admin);
-	gyrus_admin_initialize_users_tree_view (admin);
+	gyrus_admin_initialize_mailbox_tree_view (admin, FALSE);
 	gyrus_admin_initialize_acl_tree_view (admin);
+	gyrus_admin_initialize_mailbox_tree_view (admin, TRUE);
 	gyrus_admin_init_connect_signals (admin);
 	gyrus_admin_mailbox_set_sensitive (admin, FALSE);
 	gtk_widget_show (GTK_WIDGET (admin));
@@ -241,11 +301,11 @@ gyrus_admin_destroy (GtkObject *object)
 }
 
 GtkTreeModel *
-gyrus_admin_users_tree_model_new (void)
+gyrus_admin_mailbox_tree_model_new (void)
 {
 	GtkTreeModel *model;
 
-	model = GTK_TREE_MODEL(	gtk_tree_store_new (COL_USERS_NUMBER, 
+	model = GTK_TREE_MODEL(	gtk_tree_store_new (COL_MAILBOX_NUMBER, 
 						    G_TYPE_STRING, 
 						    G_TYPE_STRING,
 						    G_TYPE_STRING));
@@ -303,20 +363,26 @@ void
 gyrus_admin_get_users_list (GyrusAdmin *admin)
 {
 	GtkTreeStore *store;
+	GtkTreeStore *store_corrupt;
 	gchar *msg;
 	gchar **current_mailbox;
 	GIOError error = G_IO_ERROR_NONE;
 	gint depth, old_depth = 1;
-	GtkTreeIter iter_new, iter_parent, iter_child;
+	GtkTreeIter iter_new, iter_parent, iter_child, iter_corrupt;
 	gboolean is_valid;
-        gint n_users;
+        gint n_users, n_orphaned;
         GtkTreeViewColumn *column;
 	GyrusImapStatus status;
 	gchar *mb_name;
+	const gchar *sep_char = gyrus_admin_get_separator_char (admin);
 	
 	store =	GTK_TREE_STORE (gtk_tree_view_get_model
 				(admin->priv->treeview_users));
+	store_corrupt = GTK_TREE_STORE (gtk_tree_view_get_model 
+					(admin->priv->treeview_corrupt_mailbox));
+
 	gtk_tree_store_clear (store);
+	gtk_tree_store_clear (store_corrupt);
 
 	msg = g_strdup (". list * *\n");
 	error = gyrus_admin_write_channel (admin, msg);
@@ -328,10 +394,25 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 		mb_name = gyrus_admin_get_mailbox_from_list_message (msg);
 
 		current_mailbox = g_strsplit (mb_name, 
-					      gyrus_admin_get_separator_char (admin), 
+					      sep_char, 
 					      -1);
 
 		depth = 0;
+
+		/* this mailbox is fucked up */
+		if (current_mailbox [1] == NULL) {
+			/* add it somewhere */
+			gtk_tree_store_append (store_corrupt, &iter_corrupt, NULL);
+			gtk_tree_store_set (store_corrupt, &iter_corrupt,
+					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_NAME, mb_name,
+					    -1);
+			g_strfreev (current_mailbox);
+			g_free (msg);
+			g_free (mb_name);
+			continue;
+		}
+
 		is_valid = FALSE;
 			
 		while (current_mailbox [depth + 1] != NULL)
@@ -340,7 +421,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 		/* current folder is at same level than previous one */
 		if (depth == old_depth) {
 			gtk_tree_store_append (store, &iter_child,
-					       (depth == 1 ?
+ 					       (depth == 1 ?
 						NULL : &iter_parent));
 			is_valid = TRUE;
 		}
@@ -372,12 +453,19 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 
 		if (is_valid) {
 			gtk_tree_store_set (store, &iter_child,
-					    COL_USERS_ICON, GTK_STOCK_DIRECTORY,
-					    COL_USERS_MAILBOX, current_mailbox [depth],
-					    COL_USERS_MAILBOX_PATH, mb_name,
+					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_BASENAME, current_mailbox [depth],
+					    COL_MAILBOX_NAME, mb_name,
 					    -1);
 			old_depth = depth;
 		}
+		else {
+			gtk_tree_store_append (store_corrupt, &iter_corrupt, NULL);
+			gtk_tree_store_set (store_corrupt, &iter_corrupt,
+					    COL_MAILBOX_ICON, GTK_STOCK_DIRECTORY,
+					    COL_MAILBOX_NAME, mb_name,
+					    -1);
+		}
 		g_strfreev (current_mailbox);
 		g_free (msg);
 		g_free (mb_name);
@@ -393,27 +481,57 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 	/* get the number of users in the tree */
 	n_users = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(store), NULL);
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(admin->priv->treeview_users), 0);
-
 	msg = g_strdup_printf (_("Users (%d)"), n_users);
 	gtk_tree_view_column_set_title (column, msg);
 	g_free (msg);
+	
+	n_orphaned = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(store_corrupt), NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW(admin->priv->treeview_corrupt_mailbox), 0);
+	msg = g_strdup_printf (_("Orphaned mailboxes (%d)"), n_orphaned);
+	gtk_tree_view_column_set_title (column, msg);
+	g_free (msg);
+}
+
+gboolean
+gyrus_admin_on_treeview_focused (GtkWidget *widget,
+				 GtkDirectionType arg1,
+				 gpointer data)
+{
+	GyrusAdmin *admin = GYRUS_ADMIN (data);
+	GtkTreeSelection *selection;
+
+	g_object_set_data (G_OBJECT (admin), "selected-treeview", widget);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
+
+	gyrus_admin_on_users_selection_changed (selection, data);
+	
+	return FALSE;
 }
 
 static void
-gyrus_admin_initialize_users_tree_view (GyrusAdmin *admin)
+gyrus_admin_initialize_mailbox_tree_view (GyrusAdmin *admin, 
+					  gboolean is_orphaned)
 {
 	g_return_if_fail (GYRUS_IS_ADMIN (admin));
-
+	
+	GtkTreeView *treeview;
+	GtkTreeModel *model;
 	GtkTreeViewColumn* column;
 	GtkCellRenderer *renderer;
-	GtkTreeModel *model;
 	GtkTreeSelection *selection;
-	
-	gtk_tree_view_set_reorderable  (admin->priv->treeview_users, FALSE);
-	
-	column = gtk_tree_view_column_new ();
-	gtk_tree_view_column_set_title (column, _("Users"));
 
+	if (is_orphaned) {
+		treeview = admin->priv->treeview_corrupt_mailbox;
+	} else {
+		treeview = admin->priv->treeview_users;
+	}
+	
+	gtk_tree_view_set_reorderable  (treeview, FALSE);
+
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_column_set_title (column, 
+					is_orphaned ? _("Orphaned mailboxes") : _("Users"));
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
 	g_object_set (G_OBJECT (renderer),
@@ -421,24 +539,26 @@ gyrus_admin_initialize_users_tree_view (GyrusAdmin *admin)
 	              NULL);
 	
 	gtk_tree_view_column_set_attributes (column, renderer,
-	                                     "stock-id", COL_USERS_ICON,
+	                                     "stock-id", COL_MAILBOX_ICON,
 	                                     NULL);
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
-					     "text", COL_USERS_MAILBOX,
+					     "text", is_orphaned ? COL_MAILBOX_NAME : COL_MAILBOX_BASENAME,
 					     NULL);
 
-	gtk_tree_view_append_column (admin->priv->treeview_users, column);
+	gtk_tree_view_append_column (treeview, column);
 
-	model = gyrus_admin_users_tree_model_new ();
-	gtk_tree_view_set_model (admin->priv->treeview_users, model);
+	model = gyrus_admin_mailbox_tree_model_new ();
+	gtk_tree_view_set_model (treeview, model);
 
-	selection = gtk_tree_view_get_selection (admin->priv->treeview_users);
-	gtk_tree_selection_set_select_function (selection,
-						gyrus_admin_on_users_selection_changed,
-						admin, NULL);
+	selection = gtk_tree_view_get_selection (treeview);
+	g_signal_connect (G_OBJECT (selection), "changed", 
+			  G_CALLBACK (gyrus_admin_on_users_selection_changed), admin);
+			  
+	g_signal_connect (G_OBJECT (treeview), "focus-in-event", 
+			  G_CALLBACK (gyrus_admin_on_treeview_focused), admin);
 }
 
 GtkListStore *
@@ -541,7 +661,7 @@ gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin)
 	}
 
 	selection = gtk_tree_view_get_selection (view);
-	g_signal_connect (selection, "changed",
+	g_signal_connect (G_OBJECT (selection), "changed",
 			  G_CALLBACK (gyrus_admin_on_acl_selection_changed),
 			  admin);
 	
@@ -698,11 +818,24 @@ gyrus_admin_logout (GyrusAdmin *admin)
 }
 
 void
-gyrus_admin_logged_out (GyrusAdmin *admin)
+gyrus_admin_clean_mailbox_treeview (GtkTreeView *treeview, const gchar *title)
 {
+	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
+
 	GtkTreeStore *store;
 	GtkTreeViewColumn *column;
 	
+	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (treeview)));
+	gtk_tree_store_clear (store);
+
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 0);
+        gtk_tree_view_column_set_title (column, title);
+	
+}
+
+void
+gyrus_admin_logged_out (GyrusAdmin *admin)
+{
 	GtkWidget *btn_image;
 	
 	gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
@@ -712,26 +845,18 @@ gyrus_admin_logged_out (GyrusAdmin *admin)
 	gtk_button_set_image (GTK_BUTTON (admin->priv->button_connect),
 			      btn_image);
 
-	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (admin->priv->treeview_users)));
-	gtk_tree_store_clear (store);
-	column = gtk_tree_view_get_column(GTK_TREE_VIEW (admin->priv->treeview_users), 0);
-        gtk_tree_view_column_set_title (column, _("Users"));
+	gyrus_admin_clean_mailbox_treeview (GTK_TREE_VIEW (admin->priv->treeview_users), 
+					    _("Users"));
+	gyrus_admin_clean_mailbox_treeview (GTK_TREE_VIEW (admin->priv->treeview_corrupt_mailbox), 
+					    _("Orphaned mailboxes"));
 
 	gyrus_admin_mailbox_clear_info (admin);
 	gyrus_admin_mailbox_set_sensitive (admin, FALSE);
 	
-	if (GYRUS_IS_MAIN_APP (admin->priv->parent_app)) {
-		gyrus_main_app_menu_set_sensitive (GYRUS_MAIN_APP
-						   (admin->priv->parent_app),
-						   FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/EditMailboxRemove", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/AclEntryNew", FALSE);
-
-	}
+	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->acl_entry_selection_changed,
+		       0,
+		       NULL);
+	
 }
 
 /* returns whether the conection can be established or not. */
@@ -788,13 +913,12 @@ gyrus_admin_login (GyrusAdmin *admin)
 void
 gyrus_admin_post_login (GyrusAdmin *admin)
 {
-	if (GYRUS_IS_MAIN_APP (admin->priv->parent_app)) {
-		gyrus_main_app_menu_set_sensitive (GYRUS_MAIN_APP
-						   (admin->priv->parent_app),
-						   TRUE);
-	}
 	if (strcmp (gyrus_admin_get_separator_char (admin), "auto") == 0)
 		gyrus_admin_set_separator_char_auto (admin);
+
+	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->connected_signal_id,
+		       0,
+		       NULL);
 	
 	gyrus_admin_get_users_list (admin);
 }
@@ -867,7 +991,7 @@ gyrus_admin_select_foreach_func (GtkTreeModel *model, GtkTreePath *path,
 	
 	gchar *this_mailbox;
 	gtk_tree_model_get (model, iter,
-			    COL_USERS_MAILBOX_PATH, &this_mailbox,
+			    COL_MAILBOX_NAME, &this_mailbox,
 			    -1);
 
 	if (!strcmp (gtk_label_get_text (GTK_LABEL (admin->priv->label_mailbox_name)),
@@ -903,17 +1027,24 @@ gchar *
 gyrus_admin_get_selected_mailbox (GyrusAdmin *admin)
 {
 	GtkTreeSelection *selection;
+	GtkTreeView *treeview;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	
 	gchar *current_mailbox = NULL;
 	
-	selection = gtk_tree_view_get_selection
-		(GTK_TREE_VIEW (admin->priv->treeview_users));
+	treeview = GTK_TREE_VIEW (g_object_get_data (G_OBJECT (admin), 
+						     "selected-treeview"));
+	/* case we haven't already set it */
+	if (treeview == NULL)
+		return NULL;
+
+	selection = gtk_tree_view_get_selection	(treeview);
+
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 
 		gtk_tree_model_get (model, &iter,
-				    COL_USERS_MAILBOX_PATH, &current_mailbox,
+				    COL_MAILBOX_NAME, &current_mailbox,
 				    -1);
 	}
 	return current_mailbox;
@@ -1063,10 +1194,6 @@ gyrus_admin_on_button_connect_clicked (GtkButton *button,
 
 	if (gyrus_admin_is_connected (admin)) {
 		gyrus_admin_pre_logout (admin);
-		if (GYRUS_IS_MAIN_APP (admin->priv->parent_app))
-			gyrus_main_app_menu_set_sensitive (GYRUS_MAIN_APP
-							   (admin->priv->parent_app),
-							   FALSE);
 	} else {
 		gyrus_admin_pre_login (admin);
 	}
@@ -1089,41 +1216,27 @@ gyrus_admin_on_acl_selection_changed (GtkTreeSelection *selection,
 	GtkTreeModel *model;
 	GtkTreeIter  iter;
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter))	{
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/AclEntryDelete", TRUE);
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/AclEntryRename", TRUE);
-				
-	} else {
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/AclEntryDelete", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(GYRUS_MAIN_APP (admin->priv->parent_app),
-			 "/commands/AclEntryRename", FALSE);
-	}
+	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->acl_entry_selection_changed,
+		       0,
+		       gtk_tree_selection_get_selected (selection, &model, &iter),
+		       NULL);
 }
 
-gboolean
+void 
 gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
-					GtkTreeModel *model,
-					GtkTreePath *path,
-					gboolean path_currently_selected,
-					gpointer data)
+					gpointer          user_data) 
 {
+
 	GtkTreeIter iter;
-	GyrusAdmin *admin = GYRUS_ADMIN (data);
-	gchar *mailbox_path;
-	
-	g_return_val_if_fail (gtk_tree_model_get_iter(model, &iter, path),
-			      TRUE);
-	
-	if (!path_currently_selected) {
+	GtkTreeModel *model;
+	GyrusAdmin *admin = GYRUS_ADMIN (user_data);
+
+	gboolean is_selected = gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (is_selected)
+	{
+		gchar *mailbox_path;
 		gtk_tree_model_get (model, &iter,
-				    COL_USERS_MAILBOX_PATH, &mailbox_path,
+				    COL_MAILBOX_NAME, &mailbox_path,
 				    -1);
 
 		gchar **tokens;
@@ -1131,30 +1244,19 @@ gyrus_admin_on_users_selection_changed (GtkTreeSelection *selection,
 		gyrus_admin_mailbox_show_info (admin, tokens[1],
 					       mailbox_path);
 		g_strfreev (tokens);
-		
-		gyrus_admin_mailbox_set_sensitive (admin, TRUE);
-		if (GYRUS_IS_MAIN_APP (admin->priv->parent_app)) {
-			gyrus_main_app_menu_item_set_sensitive
-				(GYRUS_MAIN_APP (admin->priv->parent_app),
-				 "/commands/EditMailboxRemove", TRUE);
-		}
-		
 		g_free (mailbox_path);
+		gyrus_admin_mailbox_set_sensitive (admin, TRUE);
+		
 	}
 	else {
 		gyrus_admin_mailbox_clear_info (admin);
 		gyrus_admin_mailbox_set_sensitive (admin, FALSE);
-		if (GYRUS_IS_MAIN_APP (admin->priv->parent_app)) {
-			gyrus_main_app_menu_item_set_sensitive
-				(GYRUS_MAIN_APP (admin->priv->parent_app),
-				 "/commands/EditMailboxRemove", FALSE);
-			gyrus_main_app_menu_item_set_sensitive
-				(GYRUS_MAIN_APP (admin->priv->parent_app),
-				 "/commands/AclEntryNew", FALSE);
-		}
 	}
 
-	return TRUE;
+	g_signal_emit (admin, GYRUS_ADMIN_GET_CLASS (admin)->mailbox_selection_changed,
+		       0,
+		       is_selected,
+		       NULL);	
 }
 
 /***************************************
@@ -1329,7 +1431,7 @@ gyrus_admin_on_acl_identifier_edited (GtkCellRendererText *cellrenderertext,
 					    -1);
 		}
 	} else if (gyrus_admin_ask_user_if_overwrite (admin, newname)) {
-		/* DELET EXISTING ONE */
+		/* DELETE EXISTING ONE */
 		if (!gyrus_admin_acl_delete_entry (admin, mailbox,
 						   newname, &error)) {
 			g_warning (error);
