@@ -23,12 +23,13 @@
   
 */
 
-#include <libbonoboui.h>
+#include <config.h>
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <libgnomeui/libgnomeui.h>
 
-#include "gyrus-i18n.h"
+#include "glib/gi18n.h"
 #include "gyrus-dialog-mailbox-new.h"
 #include "gyrus-dialog-find-mailbox.h"
 #include "gyrus-main-app.h"
@@ -44,30 +45,27 @@ static void gyrus_main_app_destroy (GtkObject *object);
 
 static void gyrus_main_app_about (void);
 
-static BonoboWindowClass *parent_class = NULL;
+static GtkWindowClass *parent_class = NULL;
 
 /*** Class Callbacks ***/
 
 static void
-gyrus_main_app_on_file_open_session (BonoboUIComponent *component,
-				     gpointer user_data,
-				     const char *cname)
+gyrus_main_app_on_file_open_session (GtkWidget *widget G_GNUC_UNUSED,
+				     gpointer user_data)
 {
 	gyrus_session_show_sessions (NULL, user_data);
 }
 
 static void
-gyrus_main_app_on_file_exit (BonoboUIComponent *component,
-			     gpointer user_data,
-			     const char *cname)
+gyrus_main_app_on_file_exit (GtkWidget *widget G_GNUC_UNUSED, 
+			     gpointer user_data G_GNUC_UNUSED)
 {
 	gtk_main_quit ();
 }
 
 static void
-gyrus_main_app_on_edit_find (BonoboUIComponent *component,
-			     gpointer user_data,
-			     const char *cname)
+gyrus_main_app_on_edit_find (GtkWidget *widget G_GNUC_UNUSED, 
+			     gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 
@@ -83,9 +81,8 @@ gyrus_main_app_on_edit_find (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_edit_mailbox_add (BonoboUIComponent *component,
-				    gpointer user_data,
-				    const char *cname)
+gyrus_main_app_on_edit_mailbox_add (GtkWidget *widget G_GNUC_UNUSED, 
+				    gpointer user_data)
 {
 	GtkWidget *dialog =
 		gyrus_dialog_mailbox_new_new ();
@@ -107,11 +104,6 @@ gyrus_admin_delete_dialog_on_response (GtkDialog *dialog,
 		gyrus_admin_mailbox_delete_all (admin, mailbox);
 		gyrus_admin_refresh_users_list (admin);
 		gyrus_admin_mailbox_clear_info (admin);
-		if (GYRUS_IS_MAIN_APP (admin->priv->parent_app))
-			gyrus_main_app_menu_item_set_sensitive
-				(GYRUS_MAIN_APP (admin->priv->parent_app),
-				 "/commands/EditMailboxRemove",
-				 FALSE);
 		g_free (mailbox);
 	}
 
@@ -119,9 +111,8 @@ gyrus_admin_delete_dialog_on_response (GtkDialog *dialog,
 }
 
 static void
-gyrus_main_app_on_edit_mailbox_remove (BonoboUIComponent *component,
-				       gpointer user_data,
-				       const char *cname)
+gyrus_main_app_on_edit_mailbox_remove (GtkWidget *widget G_GNUC_UNUSED,
+				       gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin * admin = gyrus_main_app_get_current_admin (app);
@@ -144,17 +135,15 @@ gyrus_main_app_on_edit_mailbox_remove (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_edit_preferences (BonoboUIComponent *component,
-				    gpointer user_data,
-				    const char *cname)
+gyrus_main_app_on_edit_preferences (GtkWidget *widget G_GNUC_UNUSED,
+				    gpointer user_data)
 {
 	gyrus_preferences_show_dialog ();
 }
 
 static void
-gyrus_main_app_on_acl_entry_delete (BonoboUIComponent *component,
-				    gpointer user_data,
-				    const char *cname)
+gyrus_main_app_on_acl_entry_delete (GtkWidget *widget G_GNUC_UNUSED,
+				    gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin * admin = gyrus_main_app_get_current_admin (app);
@@ -163,9 +152,8 @@ gyrus_main_app_on_acl_entry_delete (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_acl_entry_rename (BonoboUIComponent *component,
-				    gpointer user_data,
-				    const char *cname)
+gyrus_main_app_on_acl_entry_rename (GtkWidget *widget G_GNUC_UNUSED,
+				    gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin * admin = gyrus_main_app_get_current_admin (app);
@@ -174,9 +162,8 @@ gyrus_main_app_on_acl_entry_rename (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_acl_entry_new (BonoboUIComponent *component,
-				 gpointer user_data,
-				 const char *cname)
+gyrus_main_app_on_acl_entry_new (GtkWidget *widget G_GNUC_UNUSED,
+				 gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin * admin = gyrus_main_app_get_current_admin (app);
@@ -185,9 +172,8 @@ gyrus_main_app_on_acl_entry_new (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_view_refresh (BonoboUIComponent *component,
-				gpointer user_data,
-				const char *cname)
+gyrus_main_app_on_view_refresh (GtkWidget *widget G_GNUC_UNUSED,
+				       gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin * admin = gyrus_main_app_get_current_admin (app);
@@ -195,9 +181,8 @@ gyrus_main_app_on_view_refresh (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_view_report (BonoboUIComponent *component,
-			       gpointer user_data,
-			       const char *cname)
+gyrus_main_app_on_view_report (GtkWidget *widget G_GNUC_UNUSED,
+				       gpointer user_data)
 {
 	GyrusMainApp *app  = GYRUS_MAIN_APP (user_data);
 	GyrusAdmin *admin = gyrus_main_app_get_current_admin (app);
@@ -206,9 +191,8 @@ gyrus_main_app_on_view_report (BonoboUIComponent *component,
 }
 
 static void
-gyrus_main_app_on_help_about (BonoboUIComponent *component,
-				     gpointer user_data,
-				     const char *cname)
+gyrus_main_app_on_help_about (GtkWidget *widget G_GNUC_UNUSED,
+				       gpointer user_data)
 {
 	gyrus_main_app_about();
 }
@@ -224,15 +208,9 @@ gyrus_main_app_make_sensitivity_consistent (GyrusMainApp *app)
 
 	/* If there are no pages left in Notebook */
 	if (n_page < 0) {
-		gyrus_main_app_menu_set_sensitive (app, FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryDelete", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryRename", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/EditMailboxRemove", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryNew", FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_server, FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_mailbox, FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_acl_item, FALSE);
 		return;
 	}
 	
@@ -241,21 +219,12 @@ gyrus_main_app_make_sensitivity_consistent (GyrusMainApp *app)
 					    n_page));
 	
 	if (gyrus_admin_is_connected (admin)) {
-		gyrus_main_app_menu_set_sensitive (app, TRUE);
-		if (gyrus_admin_acl_has_selection (admin)) {
-			gyrus_main_app_menu_item_set_sensitive
-				(app, "/commands/AclEntryDelete", TRUE);
-			gyrus_main_app_menu_item_set_sensitive
-				(app, "/commands/AclEntryRename", TRUE);
-		} else {
-			gyrus_main_app_menu_item_set_sensitive
-				(app, "/commands/AclEntryDelete", FALSE);
-			gyrus_main_app_menu_item_set_sensitive
-				(app, "/commands/AclEntryRename", FALSE);
-		}
+		gtk_action_group_set_sensitive (app->priv->actions_server, TRUE);
+		gtk_action_group_set_sensitive (app->priv->actions_acl_item, 
+						gyrus_admin_acl_has_selection (admin));
 	}
 	else
-		gyrus_main_app_menu_set_sensitive (app, FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_server, FALSE);
 }
 
 static void
@@ -285,8 +254,6 @@ gyrus_main_app_on_switch_page (GtkNotebook *notebook,
 			       gpointer user_data)
 {
 	GyrusMainApp *app = GYRUS_MAIN_APP (user_data);
-
-
 	GyrusAdmin *admin = GYRUS_ADMIN (gtk_notebook_get_nth_page (notebook,
 								    page_num));
 	
@@ -298,35 +265,23 @@ gyrus_main_app_on_switch_page (GtkNotebook *notebook,
 
 	gchar *mailbox;
 	if (gyrus_admin_is_connected (admin))
-		gyrus_main_app_menu_set_sensitive (app, TRUE);
+		gtk_action_group_set_sensitive (app->priv->actions_server, TRUE);
 	else
-		gyrus_main_app_menu_set_sensitive (app, FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_server, FALSE);
 
 	if ((mailbox = gyrus_admin_get_selected_mailbox (admin)) != NULL) {
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/EditMailboxRemove", TRUE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryNew",
-			 gyrus_admin_has_current_acl_access (admin));
+		gtk_action_group_set_sensitive (app->priv->actions_mailbox, 
+						TRUE);
+		if (gyrus_admin_has_current_acl_access (admin) == FALSE)
+			/* TODO: entry_new to false */ ;
 		g_free (mailbox);
 	}
 	else {
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/EditMailboxRemove", FALSE);
-			gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryNew", FALSE);
-	}
-	if (gyrus_admin_acl_has_selection (admin)) {
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryDelete", TRUE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryRename", TRUE);
-	} else {
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryDelete", FALSE);
-		gyrus_main_app_menu_item_set_sensitive
-			(app, "/commands/AclEntryRename", FALSE);
+		gtk_action_group_set_sensitive (app->priv->actions_mailbox,
+						FALSE);
 	}
+	gtk_action_group_set_sensitive (app->priv->actions_acl_item,
+					gyrus_admin_acl_has_selection (admin));
 }
 
 /*** Private Methods ***/
@@ -349,7 +304,7 @@ gyrus_main_app_get_type (void)
 				(GInstanceInitFunc) gyrus_main_app_init,
 				0
 		};
-		type = g_type_register_static (BONOBO_TYPE_WINDOW,
+		type = g_type_register_static (GTK_TYPE_WINDOW,
 					       "GyrusMainApp",
 					       &info, 0);
 	}
@@ -368,54 +323,156 @@ gyrus_main_app_class_init (GyrusMainAppClass *class)
 	object_class->destroy = gyrus_main_app_destroy;
 }
 
-static const BonoboUIVerb gyrus_main_app_verbs [] = {
-	BONOBO_UI_VERB ("FileOpenSession", gyrus_main_app_on_file_open_session),
-	BONOBO_UI_VERB ("FileExit",        gyrus_main_app_on_file_exit),
-	BONOBO_UI_VERB ("EditMailboxAdd",  gyrus_main_app_on_edit_mailbox_add),
-	BONOBO_UI_VERB ("EditMailboxRemove",
-			gyrus_main_app_on_edit_mailbox_remove),
-	BONOBO_UI_VERB ("EditFind",        gyrus_main_app_on_edit_find),
-	BONOBO_UI_VERB ("EditPreferences", gyrus_main_app_on_edit_preferences),
-	BONOBO_UI_VERB ("AclEntryNew",     gyrus_main_app_on_acl_entry_new),
-	BONOBO_UI_VERB ("AclEntryRename",  gyrus_main_app_on_acl_entry_rename),
-	BONOBO_UI_VERB ("AclEntryDelete",  gyrus_main_app_on_acl_entry_delete),
-	BONOBO_UI_VERB ("ViewRefresh",     gyrus_main_app_on_view_refresh),
-	BONOBO_UI_VERB ("ViewReport",      gyrus_main_app_on_view_report),
-	BONOBO_UI_VERB ("HelpAbout",       gyrus_main_app_on_help_about),
-	
-	BONOBO_UI_VERB_END
+static const char *ui_description =
+"<ui>\n"
+"  <menubar name='MainMenu'>\n"
+"    <menu action='FileMenu'>\n"
+"      <menuitem action='OpenSession'/>\n"
+"      <separator/>\n"
+"      <menuitem action='Quit'/>\n"
+"    </menu>\n"
+"    <menu action='EditMenu'>\n"
+"      <menuitem action='Find'/>\n"
+/*"      <separator/>\n"
+  "      <menuitem action='Preferences'/>\n"*/
+"    </menu>\n"
+"    <menu action='AclMenu'>\n"
+"      <menuitem action='EntryNew'/>\n"
+"      <menuitem action='EntryRename'/>\n"
+"      <menuitem action='EntryDelete'/>\n"
+"    </menu>\n"
+"    <menu action='ViewMenu'>\n"
+"      <menuitem action='Refresh'/>\n"
+"      <separator/>\n"
+"      <menuitem action='Report'/>\n"
+"    </menu>\n"
+"    <menu action='HelpMenu'>\n"
+"      <menuitem action='About'/>\n"
+"    </menu>\n"
+"  </menubar>\n"
+"  <toolbar name='MainToolbar'>\n"
+"    <placeholder name='placeholder1'>\n"
+"      <toolitem action='OpenSession' />\n"
+"      <separator/>\n"
+"      <toolitem action='AddMailbox' />\n"
+"      <toolitem action='RemoveMailbox' />\n"
+"      <separator/>\n"
+"      <toolitem action='Find' />\n"
+"      <separator/>\n"
+"      <toolitem action='Refresh'/>\n"
+"    </placeholder>\n"
+"  </toolbar>\n"
+"</ui>\n";
+
+static const GtkActionEntry entries_window[] = {
+  { "FileMenu", NULL, N_("_File") },
+  { "EditMenu", NULL, N_("_Edit") },
+  { "AclMenu", NULL, N_("_ACL") },
+  { "ViewMenu", NULL, N_("_View") },
+  { "HelpMenu", NULL, N_("_Help") },
+  { "OpenSession", GTK_STOCK_OPEN, N_("Go to server..."), "<control>O", 
+    N_("Show the list of servers"), G_CALLBACK (gyrus_main_app_on_file_open_session) },
+  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", 
+    N_("Quit the program"), G_CALLBACK (gyrus_main_app_on_file_exit) },
+  { "About", GTK_STOCK_ABOUT, N_("_About"), NULL, 
+    NULL, G_CALLBACK (gyrus_main_app_on_help_about) }
+/*  { "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, 
+    N_("Show the program preferences"), gyrus_main_app_on_edit_preferences } */
+};
+
+static const GtkActionEntry entries_server[] = {
+  { "AddMailbox", GTK_STOCK_ADD, N_("Add mailbox"), NULL,
+    N_("Add a mailbox under the one selected"), G_CALLBACK (gyrus_main_app_on_edit_mailbox_add) },
+  { "Find", GTK_STOCK_FIND, N_("_Find"), "<control>F", 
+    N_("Search for a mailbox in current server"), G_CALLBACK (gyrus_main_app_on_edit_find) },
+  { "Refresh", GTK_STOCK_REFRESH, N_("_Refresh"), "<control>R", 
+    N_("Refresh the mailbox list"), G_CALLBACK (gyrus_main_app_on_view_refresh) },
+  { "Report", NULL, N_("Report"), NULL, 
+    N_("Create report of users with quota problems"), G_CALLBACK (gyrus_main_app_on_view_report) }
+};
+
+static const GtkActionEntry entries_mailbox[] = {
+  { "EntryNew", NULL, N_("New entry"), "<control><shift>N", 
+    N_("Create a new ACL entry in current mailbox"), G_CALLBACK (gyrus_main_app_on_acl_entry_new) },
+  { "RemoveMailbox", GTK_STOCK_REMOVE, N_("Remove mailbox"), NULL,
+    N_("Remove current mailbox from the server"), G_CALLBACK (gyrus_main_app_on_edit_mailbox_remove) }
+};
+
+static const GtkActionEntry entries_acl_item [] = {
+
+  { "EntryRename", NULL, N_("Rename entry"), "<control><shift>R", 
+    N_("Rename selected ACL entry"), G_CALLBACK (gyrus_main_app_on_acl_entry_rename) },
+  { "EntryDelete", NULL, N_("Delete entry"), "<control><shift>D", 
+    N_("Delete selected ACL entry"), G_CALLBACK (gyrus_main_app_on_acl_entry_delete) }
 };
 
 static void
 gyrus_main_app_init (GyrusMainApp *app)
 {
-	BonoboUIContainer *ui_container;
-	BonoboUIComponent *ui_component;
+
 	GtkWidget *main_vbox;
 	GtkWidget *appbar;
-
-	ui_container = bonobo_window_get_ui_container (BONOBO_WINDOW (app));
-	bonobo_ui_engine_config_set_path (bonobo_window_get_ui_engine
-					  (BONOBO_WINDOW (app)),
-					  "/apps/gyrus/UIConfig/kvps");
-	ui_component = bonobo_ui_component_new_default ();
-	bonobo_ui_component_set_name (ui_component, "gyrus-menubar");
-	bonobo_ui_component_set_container (ui_component,
-					   BONOBO_OBJREF (ui_container), NULL);
-	
-	bonobo_ui_util_set_ui (ui_component, "",
-			       GYRUS_SCHEMAS_DIR "/gyrus.xml",
-			       "gyrus", NULL);
-
-	bonobo_ui_component_add_verb_list_with_data (ui_component,
-						     gyrus_main_app_verbs,
-						     app);
+	GtkWidget *menubar;
+	GtkWidget *toolbar;
+	GtkAccelGroup *accel_group;
+	GError *error;
 
 	app->priv = g_new0 (GyrusMainAppPrivate, 1);
 	gtk_window_set_title (GTK_WINDOW (app),
 			      _("Cyrus IMAP Administrator"));
-	bonobo_window_set_name (BONOBO_WINDOW (app), "gyrus");
+
 	main_vbox = gtk_vbox_new (FALSE, 0);
+
+	app->priv->ui_manager = gtk_ui_manager_new ();
+
+	app->priv->actions_window = gtk_action_group_new ("Window Actions");
+	gtk_action_group_set_translation_domain (app->priv->actions_window,
+						 GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (app->priv->actions_window, entries_window, 
+				      G_N_ELEMENTS (entries_window), app);
+	gtk_ui_manager_insert_action_group (app->priv->ui_manager, app->priv->actions_window, 0);
+
+	app->priv->actions_server = gtk_action_group_new ("Server Actions");
+	gtk_action_group_set_translation_domain (app->priv->actions_server,
+						 GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (app->priv->actions_server, entries_server, 
+				      G_N_ELEMENTS (entries_server), app);
+	gtk_ui_manager_insert_action_group (app->priv->ui_manager, app->priv->actions_server, 0);
+	gtk_action_group_set_sensitive (app->priv->actions_server, FALSE);
+
+	app->priv->actions_mailbox = gtk_action_group_new ("Mailbox Actions");
+	gtk_action_group_set_translation_domain (app->priv->actions_mailbox,
+						 GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (app->priv->actions_mailbox, entries_mailbox, 
+				      G_N_ELEMENTS (entries_mailbox), app);
+	gtk_ui_manager_insert_action_group (app->priv->ui_manager, app->priv->actions_mailbox, 0);
+	gtk_action_group_set_sensitive (app->priv->actions_mailbox, FALSE);
+
+	app->priv->actions_acl_item = gtk_action_group_new ("ACL Item Actions");
+	gtk_action_group_set_translation_domain (app->priv->actions_acl_item,
+						 GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (app->priv->actions_acl_item, entries_acl_item, 
+				      G_N_ELEMENTS (entries_acl_item), app);
+	gtk_ui_manager_insert_action_group (app->priv->ui_manager, app->priv->actions_acl_item, 0);
+	gtk_action_group_set_sensitive (app->priv->actions_acl_item, FALSE);
+
+	accel_group = gtk_ui_manager_get_accel_group (app->priv->ui_manager);
+	gtk_window_add_accel_group (GTK_WINDOW (app), accel_group);
+
+	error = NULL;
+	if (!gtk_ui_manager_add_ui_from_string (app->priv->ui_manager, ui_description, -1, &error))
+	{
+		g_message ("building menus failed: %s", error->message);
+		g_error_free (error);
+		exit (EXIT_FAILURE);
+	}
+	
+	menubar = gtk_ui_manager_get_widget (app->priv->ui_manager, "/MainMenu");
+	gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, FALSE, 0);
+
+	toolbar = gtk_ui_manager_get_widget (app->priv->ui_manager, "/MainToolbar");
+	gtk_box_pack_start (GTK_BOX (main_vbox), toolbar, FALSE, FALSE, 0);
+
 	app->priv->notebook = gtk_notebook_new ();
 
 	g_signal_connect (G_OBJECT (app->priv->notebook), "switch-page",
@@ -427,8 +484,9 @@ gyrus_main_app_init (GyrusMainApp *app)
 
 	gtk_box_pack_start (GTK_BOX (main_vbox), appbar,
 			    FALSE, FALSE, 0);
-	bonobo_window_set_contents (BONOBO_WINDOW (app), main_vbox);
 
+	gtk_container_add (GTK_CONTAINER (app), 
+			   main_vbox);
 	gtk_widget_show_all (main_vbox);
 }
 
@@ -478,8 +536,8 @@ gyrus_main_app_about (void)
 
 	const gchar *authors[] = {
 		"Alejandro Vald" "\xC3\xA9" "s Jim" "\xC3\xA9"
-		"nez <alejandro@gnome.cl>",
-		"Jorge Bustos Bustos <jorge@gnome.cl>",
+		"nez <avaldes@utalca.cl>",
+		"Jorge Bustos Bustos <jbustos@utalca.cl>",
 		"Claudio Saavedra "
 		"<csaavedra@alumnos.utalca.cl>",
 		NULL
@@ -553,6 +611,46 @@ gyrus_main_app_new (void)
 	return GTK_WIDGET (app);
 }
 
+static void
+main_app_on_admin_connected (GyrusAdmin *admin,
+			     gpointer *data)
+{
+	GyrusMainApp *app = GYRUS_MAIN_APP (data);
+	gtk_action_group_set_sensitive (app->priv->actions_server,
+					TRUE);
+}
+
+static void
+main_app_on_admin_disconnected (GyrusAdmin *admin,
+				gpointer *data)
+{
+	GyrusMainApp *app = GYRUS_MAIN_APP (data);
+	gtk_action_group_set_sensitive (app->priv->actions_server,
+					FALSE);
+	gtk_action_group_set_sensitive (app->priv->actions_mailbox,
+					FALSE);
+}
+
+static void
+main_app_on_acl_entry_selection_changed (GyrusAdmin *admin,
+					 gboolean selected,
+					 gpointer *data)
+{
+	GyrusMainApp *app = GYRUS_MAIN_APP (data);
+	gtk_action_group_set_sensitive (app->priv->actions_acl_item,
+					selected);
+}
+
+static void
+main_app_on_mailbox_selection_changed (GyrusAdmin *admin,
+				       gboolean selected,
+				       gpointer *data)
+{
+	GyrusMainApp *app = GYRUS_MAIN_APP (data);
+	gtk_action_group_set_sensitive (app->priv->actions_mailbox,
+					selected);
+}
+
 GtkWidget *
 gyrus_main_app_append_page (GyrusMainApp *app, GyrusSession *session)
 {
@@ -560,6 +658,23 @@ gyrus_main_app_append_page (GyrusMainApp *app, GyrusSession *session)
 	GtkWidget *hbox_label;
 	gint page_num;
 	GtkWidget *admin = gyrus_admin_new (session);
+
+	g_signal_connect (G_OBJECT (admin), "connected", 
+			  G_CALLBACK (main_app_on_admin_connected), 
+			  app);
+
+	g_signal_connect (G_OBJECT (admin), "disconnected", 
+			  G_CALLBACK (main_app_on_admin_disconnected), 
+			  app);
+	
+	g_signal_connect (G_OBJECT (admin), "acl-entry-selection-changed", 
+			  G_CALLBACK (main_app_on_acl_entry_selection_changed), 
+			  app);
+
+	g_signal_connect (G_OBJECT (admin), "mailbox-selection-changed", 
+			  G_CALLBACK (main_app_on_mailbox_selection_changed), 
+			  app);
+	
 	gyrus_admin_set_parent_app (GYRUS_ADMIN (admin),
 				    (gpointer) app);
 	
@@ -576,45 +691,15 @@ gyrus_main_app_append_page (GyrusMainApp *app, GyrusSession *session)
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (app->priv->notebook),
 				       page_num);
 	
-/*	gyrus_main_app_menu_set_sensitive (app, TRUE); */
 	return admin;
 }
 
-void
-gyrus_main_app_menu_item_set_sensitive (GyrusMainApp *app,
-					const gchar *command,
-					gboolean sensitive)
-{
-	CORBA_char *state;
-	BonoboUIEngine *ui_engine;
-	gboolean invalid;
-	
-	ui_engine = bonobo_window_get_ui_engine (BONOBO_WINDOW (app));
-	
-	state = (CORBA_char *)
-		bonobo_ui_engine_xml_get_prop (ui_engine, command,
-					       "sensitive", &invalid);
-	state[0] = (sensitive)? '1' : '0';
-
-	bonobo_ui_engine_xml_set_prop (ui_engine, command, "sensitive",
-				       state, "gyrus-menubar");
-
-	CORBA_free (state);
-}
-
 void
 gyrus_main_app_menu_set_sensitive (GyrusMainApp *app, gboolean sens)
 {
 	g_return_if_fail (GYRUS_IS_MAIN_APP (app));
-
-	gyrus_main_app_menu_item_set_sensitive
-		(app, "/commands/EditFind", sens);
-	gyrus_main_app_menu_item_set_sensitive
-		(app, "/commands/EditMailboxAdd", sens);
-	gyrus_main_app_menu_item_set_sensitive
-		(app, "/commands/ViewRefresh", sens);
-	gyrus_main_app_menu_item_set_sensitive
-                (app, "/commands/ViewReport", sens);
+	gtk_action_group_set_sensitive (app->priv->actions_server,
+					sens);
 }
 
 /***** Above functions doesnt belong this file ******/
@@ -636,7 +721,7 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 
 	gnome_program_init ("gyrus", VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv,
+ 			    argc, argv,
 			    GNOME_PARAM_APP_DATADIR, GYRUS_DATA_DIR, NULL);
 
 	app = gyrus_main_app_new ();
