@@ -23,14 +23,15 @@
   
 */
 
+#include <config.h>
+
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-/*#include <libbonoboui.h>*/
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
-#include "gyrus-i18n.h"
+#include "glib/gi18n.h"
 #include "gyrus-common.h"
 #include "gyrus-main-app.h"
 #include "gyrus-admin.h"
@@ -780,6 +781,8 @@ gyrus_session_edit_load_interface (gpointer user_data)
 	                  G_CALLBACK (gyrus_session_checkbutton_secure_toggled),
 	                  (gpointer) spinbutton_port);
 	
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox_sep_char), 0);
+
 	gtk_window_set_modal (GTK_WINDOW (window_edit), TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (window_edit), GTK_WINDOW (window));
 	gtk_widget_grab_default (button_session_edit_ok);
